@@ -81,15 +81,15 @@ setMethod("crosscorr", "codaMCMC", function(x)
 setMethod("mcpar", "codaMCMC", function(x) c(start(x), end(x), thin(x)))
 
 ## these are necessary due to virtual class mcmc.list
-setMethod("nvar", "MCMClist", function(x) coda:::nvar(x))
-setMethod("varnames", "MCMClist", function(x, ...) coda:::varnames(x, ...))
+setMethod("nvar", "MCMClist", function(x) coda::nvar(x))
+setMethod("varnames", "MCMClist", function(x, ...) coda::varnames(x, ...))
 setMethod("chanames", "MCMClist", function(x, ...) 
-    coda:::chanames(as(x, "MCMClist"), ...))
-setMethod("nchain", "MCMClist", function(x) coda:::nchain(x))
-setMethod("niter", "MCMClist", function(x) coda:::niter(x))
-setMethod("thin", "MCMClist", function(x) coda:::thin(x))
+    coda::chanames(as(x, "MCMClist"), ...))
+setMethod("nchain", "MCMClist", function(x) coda::nchain(x))
+setMethod("niter", "MCMClist", function(x) coda::niter(x))
+setMethod("thin", "MCMClist", function(x) coda::thin(x))
 setMethod("crosscorr", "MCMClist", function(x) 
-    coda:::crosscorr(x))
+    coda::crosscorr(x))
 setMethod("mcpar", "MCMClist", function(x) c(start(x), end(x), thin(x)))
 
 ## ---------------------
@@ -117,14 +117,14 @@ setMethod("confint", "dcCodaMCMC", function(object, parm, level = 0.95, ...) {
 setMethod("confint", "MCMClist", function(object, parm, level = 0.95, ...) {
     if (is.null(nclones(object)) || nclones(object) < 2)
         stop("'confint' method not defined for k=1")
-    dclone:::confint.mcmc.list.dc(object, parm, level, ...)
+    dclone::confint.mcmc.list.dc(object, parm, level, ...)
 })
 setMethod("confint", "codaMCMC", function(object, parm, level = 0.95, ...) {
     stop("'confint' method not defined for k=1")
 })
 
 setMethod("quantile", "MCMClist", function(x, ...) {
-    dclone:::quantile.mcmc.list(x, ...)
+    dclone::quantile.mcmc.list(x, ...)
 })
 setMethod("quantile", "dcmle", function(x, ...) {
     quantile(as(x, "MCMClist"), ...)
@@ -161,10 +161,10 @@ setMethod("time", "codaMCMC", function(x, ...) {
 })
 
 setMethod("window", "dcmle", function(x, ...) {
-    as(coda:::window.mcmc.list(as.mcmc.list(x), ...), "dcmle")
+    as(window(as(x, "mcmc.list"), ...), "dcmle")
 })
 setMethod("window", "codaMCMC", function(x, ...) {
-    as(coda:::window.mcmc.list(as.mcmc.list(x), ...), "codaMCMC")
+    as(window(as(x, "mcmc.list"), ...), "codaMCMC")
 })
 
 ## no update for codaMCMC/dcCodaMCMC
@@ -212,18 +212,18 @@ setMethod("stack", "codaMCMC", function(x, ...) {
 ## this displays a compact structure (without detailed dctable)
 #setGeneric("str", function(object, ...) standardGeneric("str"))
 setMethod("str", "dcmle", function(object, max.level=5L, ...) 
-    utils:::str.default(object, max.level=max.level, ...))
+    str(as(object, "MCMClist"), max.level=max.level, ...))
 setMethod("str", "dcCodaMCMC", function(object, max.level=3L, ...) 
-    utils:::str.default(object, max.level=max.level, ...))
+    str(as(object, "MCMClist"), max.level=max.level, ...))
 
 setMethod("head", "dcmle", function(x, ...) 
-    coda:::head.mcmc.list(as(x, "MCMClist"), ...))
+    head(as(x, "MCMClist"), ...))
 setMethod("tail", "dcmle", function(x, ...) 
-    coda:::tail.mcmc.list(as(x, "MCMClist"), ...))
+    tail(as(x, "MCMClist"), ...))
 setMethod("head", "codaMCMC", function(x, ...) 
-    coda:::head.mcmc.list(as(x, "MCMClist"), ...))
+    head(as(x, "MCMClist"), ...))
 setMethod("tail", "codaMCMC", function(x, ...) 
-    coda:::tail.mcmc.list(as(x, "MCMClist"), ...))
+    tail(as(x, "MCMClist"), ...))
 
 
 ## this is after mle class
@@ -435,7 +435,7 @@ setMethod("[",
 setGeneric("gelman.diag", function(x, ...) 
     standardGeneric("gelman.diag"))
 setMethod("gelman.diag", "MCMClist", function(x, ...) 
-    coda:::gelman.diag(x, ...))
+    coda::gelman.diag(x, ...))
 setMethod("gelman.diag", "codaMCMC", function(x, ...) 
     gelman.diag(as(x, "MCMClist"), ...))
 setMethod("gelman.diag", "dcmle", function(x, ...) 
@@ -444,7 +444,7 @@ setMethod("gelman.diag", "dcmle", function(x, ...)
 setGeneric("geweke.diag", function(x, ...) 
     standardGeneric("geweke.diag"))
 setMethod("geweke.diag", "MCMClist", function(x, ...) 
-    coda:::geweke.diag(x, ...))
+    coda::geweke.diag(x, ...))
 setMethod("geweke.diag", "codaMCMC", function(x, ...) 
     geweke.diag(as(x, "MCMClist"), ...))
 setMethod("geweke.diag", "dcmle", function(x, ...) 
@@ -453,7 +453,7 @@ setMethod("geweke.diag", "dcmle", function(x, ...)
 setGeneric("raftery.diag", function(x, ...) 
     standardGeneric("raftery.diag"))
 setMethod("raftery.diag", "MCMClist", function(x, ...) 
-    coda:::raftery.diag(x, ...))
+    coda::raftery.diag(x, ...))
 setMethod("raftery.diag", "codaMCMC", function(x, ...) 
     raftery.diag(as(x, "MCMClist"), ...))
 setMethod("raftery.diag", "dcmle", function(x, ...) 
@@ -462,7 +462,7 @@ setMethod("raftery.diag", "dcmle", function(x, ...)
 setGeneric("heidel.diag", function(x, ...) 
     standardGeneric("heidel.diag"))
 setMethod("heidel.diag", "MCMClist", function(x, ...) 
-    coda:::heidel.diag(x, ...))
+    coda::heidel.diag(x, ...))
 setMethod("heidel.diag", "codaMCMC", function(x, ...) 
     heidel.diag(as(x, "MCMClist"), ...))
 setMethod("heidel.diag", "dcmle", function(x, ...) 
@@ -471,7 +471,7 @@ setMethod("heidel.diag", "dcmle", function(x, ...)
 #setGeneric("autocorr.diag", function(mcmc.obj, ...) 
 #    standardGeneric("autocorr.diag"))
 setMethod("autocorr.diag", "MCMClist", function(mcmc.obj, ...) 
-    coda:::autocorr.diag.mcmc.list(mcmc.obj, ...))
+    autocorr.diag(as(mcmc.obj, "mcmc.list"), ...))
 setMethod("autocorr.diag", "codaMCMC", function(mcmc.obj, ...) 
     autocorr.diag(as(mcmc.obj, "MCMClist"), ...))
 setMethod("autocorr.diag", "dcmle", function(mcmc.obj, ...) 
@@ -480,7 +480,7 @@ setMethod("autocorr.diag", "dcmle", function(mcmc.obj, ...)
 #setGeneric("chisq.diag", function(x, ...) 
 #    standardGeneric("chisq.diag"))
 setMethod("chisq.diag", "MCMClist", function(x, ...) 
-    dclone:::chisq.diag(x))
+    dclone::chisq.diag(x))
 setMethod("chisq.diag", "codaMCMC", function(x, ...) 
     chisq.diag(as(x, "MCMClist"), ...))
 setMethod("chisq.diag", "dcmle", function(x, ...) 
@@ -489,7 +489,7 @@ setMethod("chisq.diag", "dcmle", function(x, ...)
 #setGeneric("lambdamax.diag", function(x, ...) 
 #    standardGeneric("lambdamax.diag"))
 setMethod("lambdamax.diag", "MCMClist", function(x, ...) 
-    dclone:::lambdamax.diag(x))
+    dclone::lambdamax.diag(x))
 setMethod("lambdamax.diag", "codaMCMC", function(x, ...) 
     lambdamax.diag(as(x, "MCMClist"), ...))
 setMethod("lambdamax.diag", "dcmle", function(x, ...) 
